# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
from mssqlctl.cli.core.deploy import get_config_profiles


def load_arguments(self, _):
    from knack.arguments import ArgumentsContext
    from mssqlctl.cli.commands.control import _

    with ArgumentsContext(self, 'control create') as arg_context:
        arg_context.argument(
            'name',
            options_list=('--name', '-n'),
            help=_('Control plane name, used for kubernetes namespaces.')
        )

        arg_context.argument(
            'config_profile',
            options_list=('--config-profile', '-c'),
            help=_('Cluster config profile, used for deploying the cluster: {0}').format(
                list(get_config_profiles().keys()))
        )

        arg_context.argument(
            'accept_eula',
            options_list=('--accept-eula', '-a'),
            help='Do you accept the license terms? [yes/no]. If you do not want to use this arg, '
                 'you may set the environment variable ACCEPT_EULA to \'yes\'. The license terms for this product can '
                 'be viewed at https://aka.ms/eula-azdata-en.'
        )

        arg_context.argument(
            'node_label',
            options_list=('--node-label', '-l'),
            help=_('Node label, used to designate what nodes to deploy to.')
        )

        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force create, the user will not be prompted for any values and all issues will be printed as part'
                   'of stderr.')
        )

    with ArgumentsContext(self, 'control delete') as arg_context:
        arg_context.argument(
            'name',
            options_list=('--name', '-n'),
            help=_('Control plane name, used for kubernetes namespace.')
        )

        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force delete control plane.'))
